@@ -63,7 +63,7 @@ class FileFactory:
         once for all
 
 
-    Some files may be prefixed with a common name separated by a dot. For example, 
+    Some files may be prefixed with a common name separated by a dot. For example,
     with pacbio data you may have::
 
         demultiplex.A.fastq.gz
@@ -74,22 +74,21 @@ class FileFactory:
 
     """
 
-    def __init__(self, pattern, extra_prefixes_to_strip=[], 
-        sample_pattern=None, **kwargs):
+    def __init__(self, pattern, extra_prefixes_to_strip=[], sample_pattern=None, **kwargs):
         """.. rubric:: Constructor
 
         :param pattern: can be a filename, list of filenames, or a global
             pattern (a unix regular expression with wildcards). For instance,
             ``*/*fastq.gz``
         :param extra_prefixes_to_strip: we automatically remove common prefixes.
-            However, you may have extra prefixes not common to all samples 
-            that needs to be removed. Provide a list with extra_prefixes_to_strip 
+            However, you may have extra prefixes not common to all samples
+            that needs to be removed. Provide a list with extra_prefixes_to_strip
             including trailing dot or not.
         :param sample_pattern: if a sample pattern is provided, prefix are
             not removed automatically. The sample_pattern must include the string
-            {sample} to define the expected sample name. For instance given 
+            {sample} to define the expected sample name. For instance given
             a filename A_sorted.fastq.gz where sorted appears in all sample
-            buy is not wished, use sample_pattern='{sample}_sorted.fastq.gz' 
+            buy is not wished, use sample_pattern='{sample}_sorted.fastq.gz'
             and your sample will be only 'A'.
 
         """
@@ -105,13 +104,13 @@ class FileFactory:
         except TypeError:
             # Error if pattern is a list of file
             for filename in pattern:
-                if not os.path.exists(filename):
+                if not os.path.exists(filename):  # pragma: no cover
                     raise FileNotFoundError(f"This file {filename} does not exist")
             self._glob = pattern[:]
 
         # remove directories if they exist
         self._glob = [x for x in self._glob if not os.path.isdir(x)]
-        
+
     def _get_realpaths(self):
         return [os.path.realpath(filename) for filename in self._glob]
 
@@ -130,50 +129,51 @@ class FileFactory:
         # if only one sample, we do not alter the sample name.
         # we just take the first word.
         if len(self._glob) > 1 and not self.sample_pattern:
-            splitted = [x.split('.') for x in self.basenames]
-            min_split = min([len(x) for x in splitted]) 
+            splitted = [x.split(".") for x in self.basenames]
+            min_split = min([len(x) for x in splitted])
             for i in range(min_split):
-                S = set([x[i] for x in splitted])                
+                S = set([x[i] for x in splitted])
                 if len(S) == 1:
                     # a redundant prefix to remove
                     prefixes_to_strip.append(S.pop() + ".")
                 elif len(S) == len(self._glob):
                     # we found different sample name; we can stop here
                     break
-                else:
-                    # if we have a mix of names with duplicated names, this 
-                    # will be problem but users may provide a solution by 
-                    # providing other prefixes to remove so not exception here. 
+                else:  # pragma: no cover
+                    # if we have a mix of names with duplicated names, this
+                    # will be problem but users may provide a solution by
+                    # providing other prefixes to remove so not exception here.
                     # Will be raised later if needed
                     pass
 
         # Even though we now have unique samples names, some prefixes
         # from the users can still be stripped from the left hand side
         # we remove the dot (if it exists) and add one to be sure it is
-        # there.        
-        prefixes_to_strip += [x.strip('.') + '.' for x in self.extra_prefixes_to_strip]
+        # there.
+        prefixes_to_strip += [x.strip(".") + "." for x in self.extra_prefixes_to_strip]
 
         def func(filename):
 
             # if sample pattern is provided, use it in place of the prefixes
             if self.sample_pattern:
-                prefix, suffix =self.sample_pattern.split("{sample}")
+                prefix, suffix = self.sample_pattern.split("{sample}")
                 res = filename[:]
 
                 if filename.startswith(prefix) and filename.endswith(suffix):
-                    res = res[len(prefix):len(res)-len(suffix)]
+                    res = res[len(prefix) : len(res) - len(suffix)]
                 else:
                     raise PipetoolsException(f"Your sample pattern does not match the filename {filename}")
             else:
                 res = filename[:]
                 for prefix in prefixes_to_strip:
-                    res = res[res.startswith(prefix) and len(prefix):]
+                    res = res[res.startswith(prefix) and len(prefix) :]
             return res.split(".")[0]
-                    
-                    
+
         filenames = [func(basename) for basename in self.basenames]
         if len(set(filenames)) != len(self._glob):
-            raise PipetoolsException(f"Your sample names do not seem to be unique. After removing some common prefixes ({prefixes_to_strip}), we end up with {filenames}")
+            raise PipetoolsException(
+                f"Your sample names do not seem to be unique. After removing some common prefixes ({prefixes_to_strip}), we end up with {filenames}"
+            )
 
         return filenames
 
@@ -181,14 +181,17 @@ class FileFactory:
 
     def _get_pathnames(self):
         return [os.path.split(filename)[0] for filename in self.realpaths]
+
     pathnames = property(_get_pathnames, doc="path and filename (e.g., /home/user/readme")
 
     def _get_extensions(self):
         return [os.path.splitext(filename)[1] for filename in self._glob]
+
     extensions = property(_get_extensions, doc="get final extension    ")
 
     def _get_all_extensions(self):
         return [basename.split(".", 1)[1] if "." in basename else "" for basename in self.basenames]
+
     all_extensions = property(_get_all_extensions, doc=" get all trailing extensions")
 
     def _pathname(self):
@@ -238,7 +241,7 @@ class FastQFactory(FileFactory):
 
         FastQFactory("*ccs.fastq.gz", read_tag=None)
 
-    In such case, the :attr:`paired` is set to False. 
+    In such case, the :attr:`paired` is set to False.
 
     In a directory (recursively or not), there could be lots of samples. This
     class can be used to get all the sample prefix in the :attr:`tags`
@@ -255,11 +258,16 @@ class FastQFactory(FileFactory):
 
     """
 
-    def __init__(self, pattern, extension=["fq.gz", "fastq.gz"], 
-                read_tag="_R[12]_", 
-                #verbose=False, paired=True, 
-                extra_prefixes_to_strip=[], 
-                sample_pattern=None, **kwargs):
+    def __init__(
+        self,
+        pattern,
+        extension=["fq.gz", "fastq.gz"],
+        read_tag="_R[12]_",
+        # verbose=False, paired=True,
+        extra_prefixes_to_strip=[],
+        sample_pattern=None,
+        **kwargs,
+    ):
         r""".. rubric:: Constructor
 
         :param str pattern: a global pattern (e.g., ``H*fastq.gz``)
@@ -268,19 +276,19 @@ class FastQFactory(FileFactory):
             characters need to be escaped with a \ character to be interpreted as
             character. (e.g. '_R[12]_\.fastq\.gz')
         :param extra_prefixes_to_strip: we automatically remove common prefixes.
-            However, you may have extra prefixes not common to all samples 
-            that needs to be removed. Provide a list with extra_prefixes_to_strip 
+            However, you may have extra prefixes not common to all samples
+            that needs to be removed. Provide a list with extra_prefixes_to_strip
             including trailing dot or not.
         :param sample_pattern: if a sample pattern is provided, prefix are
             not removed automatically. The sample_pattern must include the string
-            {sample} to define the expected sample name. For instance given 
+            {sample} to define the expected sample name. For instance given
             a filename A_sorted.fastq.gz where sorted appears in all sample
-            buy is not wished, use sample_pattern='{sample}_sorted.fastq.gz' 
+            buy is not wished, use sample_pattern='{sample}_sorted.fastq.gz'
             and your sample will be only 'A'.
         """
-        super(FastQFactory, self).__init__(pattern, 
-            extra_prefixes_to_strip=extra_prefixes_to_strip,
-            sample_pattern=sample_pattern)
+        super(FastQFactory, self).__init__(
+            pattern, extra_prefixes_to_strip=extra_prefixes_to_strip, sample_pattern=sample_pattern
+        )
 
         self.read_tag = read_tag
         # Filter out reads that do not have the read_tag
@@ -292,10 +300,8 @@ class FastQFactory(FileFactory):
             remaining = [filename for filename in self._glob if re.search(self.read_tag, os.path.basename(filename))]
             if len(remaining) < len(self._glob):
                 diff = len(self._glob) - len(remaining)
-                logger.warning(
-                    f"Filtered out {diff} files that do not contain the read_tag ({self.read_tag})"
-                    )
-                
+                logger.warning(f"Filtered out {diff} files that do not contain the read_tag ({self.read_tag})")
+
             self._glob = remaining
 
         # check if tag is informative
